Supvisors status

| Name | State | Supervisor | Description | %Load | %CPU | %MEM | Actions | Log
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Name | State | Supervisor | Description | %Load | %CPU | %MEM | Actions | Log
| -- | -- | -- | -- | -- | -- | -- | Start | Stop | Restart | Clear | Stdout | Stderr

| Detailed Statistics
--- | ---
Process: |
Node: |
IP Address: |

%CPU
Latest | Mean | Slope/P | StdDev
--- | --- | --- | ---
-- | -- | -- | --

%MEM
Latest | Mean | Slope/P | StdDev
--- | --- | --- | ---
-- | -- | -- | --

on